==> getsocial_flutter_sdk-7.2.2.tar.gz: lib/src/native_bridge.dart <==
import 'package:flutter/services.dart';

class NativeBridge {
  static const MethodChannel _methods =
      const MethodChannel('im.getsocial.flutter/methods');
  static const EventChannel _initializationEvent =
      const EventChannel('im.getsocial.flutter/event/initialization');
  static const EventChannel _currentUserChangedEvent =
      const EventChannel('im.getsocial.flutter/event/currentuserchanged');
  static const EventChannel _referralDataReceivedEvent =
      const EventChannel('im.getsocial.flutter/event/referraldatareceived');
  static const EventChannel _notificationReceivedEvent =
      const EventChannel('im.getsocial.flutter/event/notificationreceived');
  static const EventChannel _notificationClickedEvent =
      const EventChannel('im.getsocial.flutter/event/notificationclicked');
  static const EventChannel _notificationTokenReceivedEvent =
      const EventChannel(
          'im.getsocial.flutter/event/notificationtokenreceived');

  static Future<String> sync(String method, String body) async {
    final String response = await _methods
        .invokeMethod('callSync', {'body': body, 'method': method});
    return response;
  }

  static Future<String> async(String method, String body) async {
    final String response = await _methods
        .invokeMethod('callAsync', {'body': body, 'method': method});
    return response;
  }

  static void registerListener(String name, Function(String) listener) {
    if (name == 'GetSocial.addOnInitializedListener') {
      _initializationEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'GetSocial.addOnCurrentUserChangedListener') {
      _currentUserChangedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'Invites.setOnReferralDataReceivedListener') {
      _referralDataReceivedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'Notifications.setOnNotificationReceivedListener') {
      _notificationReceivedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'Notifications.setOnNotificationClickedListener') {
      _notificationClickedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'Notifications.setOnTokenReceivedListener') {
      _notificationTokenReceivedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    }
  }
}

==> getsocial_flutter_sdk-7.3.0.tar.gz: lib/src/native_bridge.dart <==
// ignore: import_of_legacy_library_into_null_safe
import 'package:flutter/services.dart';

class NativeBridge {
  static const MethodChannel _methods =
      const MethodChannel('im.getsocial.flutter/methods');
  static const EventChannel _initializationEvent =
      const EventChannel('im.getsocial.flutter/event/initialization');
  static const EventChannel _currentUserChangedEvent =
      const EventChannel('im.getsocial.flutter/event/currentuserchanged');
  static const EventChannel _referralDataReceivedEvent =
      const EventChannel('im.getsocial.flutter/event/referraldatareceived');
  static const EventChannel _notificationReceivedEvent =
      const EventChannel('im.getsocial.flutter/event/notificationreceived');
  static const EventChannel _notificationClickedEvent =
      const EventChannel('im.getsocial.flutter/event/notificationclicked');
  static const EventChannel _notificationTokenReceivedEvent =
      const EventChannel(
          'im.getsocial.flutter/event/notificationtokenreceived');

  static Future<String> sync(String method, String? body) async {
    final String? response = await _methods
        .invokeMethod('callSync', {'body': body, 'method': method});
    return response == null ? '{"result":""}' : response;
  }

  static Future<String> async(String method, String? body) async {
    final String? response = await _methods
        .invokeMethod('callAsync', {'body': body, 'method': method});
    return response == null ? '{"result":""}' : response;
  }

  static void registerListener(String name, Function(String) listener) {
    if (name == 'GetSocial.addOnInitializedListener') {
      _initializationEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'GetSocial.addOnCurrentUserChangedListener') {
      _currentUserChangedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'Invites.setOnReferralDataReceivedListener') {
      _referralDataReceivedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'Notifications.setOnNotificationReceivedListener') {
      _notificationReceivedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'Notifications.setOnNotificationClickedListener') {
      _notificationClickedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    } else if (name == 'Notifications.setOnTokenReceivedListener') {
      _notificationTokenReceivedEvent
          .receiveBroadcastStream(name)
          .listen((any) => {listener(any as String)});
    }
  }
}
